﻿package com.Islands 
{
	import flash.filters.ConvolutionFilter;
	import org.flixel.*;
	
	public class Player extends FlxSprite
	{
		protected var _existsClone:Boolean = false;
		
		protected var _speed:Number = 200;
		
		[Embed(source = '../../gfx/player.png')] private var ImgPlayer:Class;
		
		protected var _diedbefore:uint = 10;
		
		protected var _wasonfloor:Boolean = true;
		
		public function Player() 
		{
			super(0,0);
			loadGraphic(ImgPlayer, true, true, Islands.TILE_SIZE);
			
			width = 4;
			height = 14;
			
			offset.x = 6;
			offset.y = 1;
			
			facing = RIGHT;
			
			maxVelocity.x  = 80;
			maxVelocity.y  = 150;
			acceleration.x = 0;
			acceleration.y = 400;
			drag.x = 120;
			drag.y = 0;
			
			addAnimation("idle", [0], 1, true);
			addAnimation("jump", [3], 1, true);
			addAnimation("walk", [1, 0, 2, 0], 5, true);
			
			play("idle");
		}
		
		override public function hitLeft(Contact:FlxObject, Velocity:Number):void 
		{
			super.hitLeft(Contact, Velocity);
			
			if (Contact is Enemy || (FlxG.state as GameState).IsWaterSet(Contact))
				kill();
		}
		
		override public function hitBottom(Contact:FlxObject, Velocity:Number):void 
		{
			super.hitBottom(Contact, Velocity);
			if (Contact is Enemy || (FlxG.state as GameState).IsWaterSet(Contact))
				kill();
		}
		
		override public function hitRight(Contact:FlxObject, Velocity:Number):void 
		{
			super.hitRight(Contact, Velocity);
			if (Contact is Enemy || (FlxG.state as GameState).IsWaterSet(Contact))
				kill();
		}
		
		override public function hitTop(Contact:FlxObject, Velocity:Number):void 
		{
			super.hitTop(Contact, Velocity);
			if (Contact is Enemy || (FlxG.state as GameState).IsWaterSet(Contact))
				kill();
		}
		
		override public function kill():void 
		{
			SoundLibrary.PlaySound(SoundLibrary.SOUND_HURT);
			FlxG.quake.start();
			(FlxG.state as GameState).Spawn();
			_diedbefore = 0;
		}
		
		public function get DiedLately():Boolean
		{
			return _diedbefore < 3;
		}
		
		override public function update():void 
		{
			var jump_power:Number = 800;
			_diedbefore++;
			var moving:Boolean = false;
			
			if (!_existsClone)
			{
				
				if (FlxG.keys.RIGHT || FlxG.keys.D)
				{
					facing = RIGHT;
					velocity.x += _speed * FlxG.elapsed;
					if (onFloor)
					{
						play("walk");
						//SoundLibrary.KeepPlaying(SoundLibrary.SOUND_FOOTSTEPS);
					}
					moving = true;
				}
				else if (FlxG.keys.LEFT || FlxG.keys.A)
				{
					facing = LEFT;
					velocity.x -= _speed * FlxG.elapsed;
					if (onFloor)
					{
						play("walk");
						//SoundLibrary.KeepPlaying(SoundLibrary.SOUND_FOOTSTEPS);
					}
					moving = true;
				}
				
				if (FlxG.keys.justPressed("X"))
				{
					if (onFloor)
					{
						velocity.y = -jump_power;
						moving = true;
						SoundLibrary.PlaySound(SoundLibrary.SOUND_JUMP);
					}
				}
			
			}
			
			if (!moving)
				play("idle");
			if (!onFloor)
			{
				play("jump");
				_wasonfloor = false;
			}
			else
			{
				//if (!_wasonfloor)
					//SoundLibrary.PlaySound(SoundLibrary.SOUND_HIT_GROUND);
				_wasonfloor = true;
			}
			
			if (y > Islands.TILE_SIZE * 50)
				kill();
			super.update();
		}
		
		public function set ExistsClone(ex:Boolean):void
		{
			_existsClone = ex;
		}
		
		public function get ExistsClone():Boolean
		{
			
			return _existsClone;
		}
		
		public function get Speed():Number
		{
			return _speed;
		}
	}
}