﻿package com.Islands 
{
	import org.flixel.*;
	import org.flixel.data.FlxAnim;
	
	public class PlayerClone extends FlxSprite
	{
		protected var _player:Player;
		
		protected var _elapsed:Number;
		protected var _lifetime:Number = 2;
		[Embed(source = '../../gfx/player.png')] private var ImgPlayer:Class;
		protected var _jump_power:Number = 800;
		
		public function PlayerClone(player:Player)
		{
			super(player.x, player.y);
			
			loadGraphic(ImgPlayer, true, true, Islands.TILE_SIZE);
			
			_player = player;
			exists = false;
			visible = false;
			
			width = 4;
			height = 14;
			
			offset.x = 6;
			offset.y = 1;
			
			addAnimation("idle", [4], 1, true);
			addAnimation("jump", [7], 1, true);
			addAnimation("walk", [5, 4, 6, 4], 5, true);
			
			play("idle");
		}
		
		public function setclone():void 
		{
			super.reset(_player.x, _player.y);
			SoundLibrary.PlaySound(SoundLibrary.SOUND_GHOST_EXISTS, 0.2);
			facing = _player.facing;
			
			FlxG.follow(this, Islands.LERP);
			
			velocity.x = _player.velocity.x;
			velocity.y = _player.velocity.y - _jump_power;
			acceleration.x = _player.acceleration.x;
			acceleration.y = _player.acceleration.y;
			drag.x = 0; //_player.drag.x;
			drag.y = 0; // _player.drag.y;
			
			maxVelocity.x = _player.maxVelocity.x;
			maxVelocity.y = _player.maxVelocity.y;
			_elapsed = 0;
			visible = true;
			
			_player.ExistsClone = true;
		}
		
		public function RelinquishCommand():void
		{
			visible = false;
			_player.ExistsClone = false;
			FlxG.follow(_player, Islands.LERP);
			//FlxG.log("Remaining lifetime: " + (_lifetime - _elapsed));
			SoundLibrary.StopSound(SoundLibrary.SOUND_GHOST_EXISTS, 0.2);
			kill();
		}
		
		override public function update():void 
		{
			if (exists)
			{
				var moving:Boolean = false;
				
				if (_player.DiedLately)
					RelinquishCommand();
					
				_elapsed += FlxG.elapsed;
				if (_elapsed >= _lifetime)
				{
					RelinquishCommand();
				}
				else
				{
					if (FlxG.keys.RIGHT || FlxG.keys.D)
					{
						facing = RIGHT;
						moving = true;
						if (onFloor)
							play("walk");
						velocity.x += _player.Speed * FlxG.elapsed;
					}
					else if (FlxG.keys.LEFT || FlxG.keys.A)
					{
						facing = LEFT;
						if (onFloor)
							play("walk");
						moving = true;
						velocity.x -= _player.Speed * FlxG.elapsed;
					}
				}
				
				if (!moving)
					play("idle");
				if (!onFloor)
					play("jump");
				
				var thealpha:Number = 1 - _elapsed/_lifetime;
				alpha = Math.max(thealpha, 0);
				//if (thealpha <= 0)
					//this.visible = false;

			}
			super.update();
		}
		
		protected function CheckAndPerformSwap(Contact:FlxObject):Boolean
		{
			if (Contact is Enemy)
			{
				//FlxG.log("Remaining lifetime: " + (_lifetime - _elapsed));
				var theen:Enemy = Contact as Enemy;
				theen.velocity.x = theen.velocity.y = 0;
				
				//FlxG.log("About to move enemy (" + theen.x + ", " + theen.y + ") to player (" + _player.x + ", " + _player.y + ")");
				var way_far_away:FlxPoint = new FlxPoint( -100, -100);
				var temppoint:FlxPoint = new FlxPoint(theen.x, theen.y);
				var tempplayer:FlxPoint = new FlxPoint(_player.x, _player.y);
				theen.x = way_far_away.x;
				theen.y = way_far_away.y;
				_player.x = temppoint.x;
				_player.y = temppoint.y;
				
				theen.x = tempplayer.x;
				theen.y = tempplayer.y;
				
				SoundLibrary.PlaySound(SoundLibrary.SOUND_SWAP_PLACES);
				RelinquishCommand();
				return true;
			}
			else
			{
				if((FlxG.state as GameState).IsWaterSet(Contact))
					RelinquishCommand();
			}
			return false;
		}
		
		override public function hitBottom(Contact:FlxObject, Velocity:Number):void 
		{
			if(!CheckAndPerformSwap(Contact))
				super.hitBottom(Contact, Velocity);
		}
		
		override public function hitLeft(Contact:FlxObject, Velocity:Number):void 
		{
			if(!CheckAndPerformSwap(Contact))
				super.hitLeft(Contact, Velocity);
		}
		
		override public function hitRight(Contact:FlxObject, Velocity:Number):void 
		{
			if(!CheckAndPerformSwap(Contact))
				super.hitRight(Contact, Velocity);
		}
		
		override public function hitTop(Contact:FlxObject, Velocity:Number):void 
		{
			if(!CheckAndPerformSwap(Contact))
				super.hitTop(Contact, Velocity);
		}
		
	}
}